@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
-   Copyright (C) 2003 Waldo Bastian <bastian@kde.org>
-   Copyright (C) 2003, 2007 David Faure <faure@kde.org>
+   SPDX-FileCopyrightText: 2003 Waldo Bastian <bastian@kde.org>
+   SPDX-FileCopyrightText: 2003, 2007 David Faure <faure@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License version 2 or at your option version 3 as published by
-   the Free Software Foundation.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only
 */
 
 #include "mimetypedata.h"
@@ -419,7 +406,8 @@ void MimeTypeData::syncServices()
 
     // Clean out any kde-mimeapps.list which would take precedence any cancel our changes.
     const QString desktops = QString::fromLocal8Bit(qgetenv("XDG_CURRENT_DESKTOP"));
-    foreach (const QString &desktop, desktops.split(QLatin1Char(':'), Qt::SkipEmptyParts)) {
+    const auto desktopsSplit = desktops.split(QLatin1Char(':'), Qt::SkipEmptyParts);
+    for (const QString &desktop : desktopsSplit) {
         const QString file =
             QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + QLatin1Char('/') + desktop.toLower() + QLatin1String("-mimeapps.list");
         if (QFileInfo::exists(file)) {
